boofun.core.batch\_processing
=============================

.. automodule:: boofun.core.batch_processing


   .. rubric:: Functions

   .. autosummary::

      get_batch_processor_stats
      process_batch
      set_batch_thresholds

   .. rubric:: Classes

   .. autosummary::

      BatchProcessor
      BatchProcessorManager
      OptimizedANFProcessor
      OptimizedFourierProcessor
      OptimizedTruthTableProcessor
      ParallelBatchProcessor
      VectorizedBatchProcessor
